# Changelog

## 0.1.0-alpha.15 (2024-12-17)

Full Changelog: [v0.1.0-alpha.14...v0.1.0-alpha.15](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.14...v0.1.0-alpha.15)

### Features

* **api:** create and update evaluation ([#68](https://github.com/haizelabs/haizelabs-python/issues/68)) ([ceb48da](https://github.com/haizelabs/haizelabs-python/commit/ceb48da015a6586514c3db415a63e99170a636f3))

## 0.1.0-alpha.14 (2024-12-17)

Full Changelog: [v0.1.0-alpha.13...v0.1.0-alpha.14](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.13...v0.1.0-alpha.14)

### Features

* **api:** api key ([#55](https://github.com/haizelabs/haizelabs-python/issues/55)) ([f8b7d10](https://github.com/haizelabs/haizelabs-python/commit/f8b7d10b067086435570b638b6d24e71ab0a2599))
* **api:** api update ([#56](https://github.com/haizelabs/haizelabs-python/issues/56)) ([62d74e0](https://github.com/haizelabs/haizelabs-python/commit/62d74e0f3c10a30159f9affb1e3ea5861a66c5df))
* **api:** api update ([#65](https://github.com/haizelabs/haizelabs-python/issues/65)) ([deef7f4](https://github.com/haizelabs/haizelabs-python/commit/deef7f4276a2d774de040ef4f7a564b2de8d4400))
* **api:** api update ([#66](https://github.com/haizelabs/haizelabs-python/issues/66)) ([f61ec02](https://github.com/haizelabs/haizelabs-python/commit/f61ec0284bdd54a09160de3d87755998f79310c0))
* **api:** manual updates ([#53](https://github.com/haizelabs/haizelabs-python/issues/53)) ([47b3b1d](https://github.com/haizelabs/haizelabs-python/commit/47b3b1d194cea1d9113b6382de942a664cff4f89))


### Chores

* **internal:** add support for TypeAliasType ([#61](https://github.com/haizelabs/haizelabs-python/issues/61)) ([d58b8ba](https://github.com/haizelabs/haizelabs-python/commit/d58b8badac7a0519e81f409b26349a46fc0dee30))
* **internal:** bump pydantic dependency ([#58](https://github.com/haizelabs/haizelabs-python/issues/58)) ([4db6482](https://github.com/haizelabs/haizelabs-python/commit/4db6482efa056806ac9b6c54f03745123ef0b262))
* **internal:** bump pyright ([#60](https://github.com/haizelabs/haizelabs-python/issues/60)) ([30beb3d](https://github.com/haizelabs/haizelabs-python/commit/30beb3da8e1ee29d7a06b5fb2dcfb1f9ccfe439b))
* **internal:** codegen related update ([#57](https://github.com/haizelabs/haizelabs-python/issues/57)) ([fe19aa0](https://github.com/haizelabs/haizelabs-python/commit/fe19aa002334b3a17c0f14d51f69ddb0d59f40de))
* **internal:** codegen related update ([#62](https://github.com/haizelabs/haizelabs-python/issues/62)) ([484241a](https://github.com/haizelabs/haizelabs-python/commit/484241ac7f322c597041c2938e51689790da74ce))
* **internal:** codegen related update ([#63](https://github.com/haizelabs/haizelabs-python/issues/63)) ([fd3c5cf](https://github.com/haizelabs/haizelabs-python/commit/fd3c5cfaffa2416187737f1f537c7dec21cad576))
* **internal:** updated imports ([#64](https://github.com/haizelabs/haizelabs-python/issues/64)) ([a290586](https://github.com/haizelabs/haizelabs-python/commit/a290586ac17de002ed0c47dabb5a73c358a1bb1e))


### Documentation

* **readme:** fix http client proxies example ([#59](https://github.com/haizelabs/haizelabs-python/issues/59)) ([67f1ba2](https://github.com/haizelabs/haizelabs-python/commit/67f1ba22b91583f4f41f19ad8123c66c31b0f77e))

## 0.1.0-alpha.13 (2024-12-08)

Full Changelog: [v0.1.0-alpha.12...v0.1.0-alpha.13](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.12...v0.1.0-alpha.13)

### Chores

* update SDK settings ([#50](https://github.com/haizelabs/haizelabs-python/issues/50)) ([8cc4d5a](https://github.com/haizelabs/haizelabs-python/commit/8cc4d5a583f7e795bcdb3e1e71a6a992f1515fe6))

## 0.1.0-alpha.12 (2024-12-07)

Full Changelog: [v0.1.0-alpha.11...v0.1.0-alpha.12](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.11...v0.1.0-alpha.12)

### Features

* **api:** api update ([#47](https://github.com/haizelabs/haizelabs-python/issues/47)) ([27f7888](https://github.com/haizelabs/haizelabs-python/commit/27f7888a2571c0a07d89d9e60184b9a87327b82f))
* **api:** manual updates ([#44](https://github.com/haizelabs/haizelabs-python/issues/44)) ([eef7862](https://github.com/haizelabs/haizelabs-python/commit/eef7862d3c2091019a000c489240e8cb8d1cd4f8))

## 0.1.0-alpha.11 (2024-12-07)

Full Changelog: [v0.1.0-alpha.10...v0.1.0-alpha.11](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.10...v0.1.0-alpha.11)

### Features

* **api:** api update ([#42](https://github.com/haizelabs/haizelabs-python/issues/42)) ([1a795a8](https://github.com/haizelabs/haizelabs-python/commit/1a795a8fb67d375ab626acc393b01662c11eaa2c))


### Chores

* **internal:** bump pyright ([#40](https://github.com/haizelabs/haizelabs-python/issues/40)) ([ba76f8b](https://github.com/haizelabs/haizelabs-python/commit/ba76f8b74069c9764dcd98a990859eb6f1455a8b))

## 0.1.0-alpha.10 (2024-12-03)

Full Changelog: [v0.1.0-alpha.9...v0.1.0-alpha.10](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.9...v0.1.0-alpha.10)

### Features

* **api:** manual updates ([#37](https://github.com/haizelabs/haizelabs-python/issues/37)) ([b562064](https://github.com/haizelabs/haizelabs-python/commit/b562064d10c8a2117cd65144153812654b174542))

## 0.1.0-alpha.9 (2024-12-03)

Full Changelog: [v0.1.0-alpha.8...v0.1.0-alpha.9](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.8...v0.1.0-alpha.9)

### Features

* **api:** api update ([#28](https://github.com/haizelabs/haizelabs-python/issues/28)) ([8d94847](https://github.com/haizelabs/haizelabs-python/commit/8d9484786a5ec3611fad7fb4854c52b20615cfe0))
* **api:** api update ([#35](https://github.com/haizelabs/haizelabs-python/issues/35)) ([518981d](https://github.com/haizelabs/haizelabs-python/commit/518981d6e917a9f294770ef38e60d4ab893bff22))


### Bug Fixes

* **client:** compat with new httpx 0.28.0 release ([#34](https://github.com/haizelabs/haizelabs-python/issues/34)) ([0c0ee49](https://github.com/haizelabs/haizelabs-python/commit/0c0ee49e3fff364dad4588408fd3c0efa431d395))


### Chores

* **internal:** codegen related update ([#31](https://github.com/haizelabs/haizelabs-python/issues/31)) ([66846eb](https://github.com/haizelabs/haizelabs-python/commit/66846ebcdb081ac2807720d616944838ca44d8e3))
* **internal:** exclude mypy from running on tests ([#33](https://github.com/haizelabs/haizelabs-python/issues/33)) ([09ffde0](https://github.com/haizelabs/haizelabs-python/commit/09ffde0ad9cd608d22cbca5d081b6fe1acfb00dd))
* **internal:** fix compat model_dump method when warnings are passed ([#30](https://github.com/haizelabs/haizelabs-python/issues/30)) ([7905667](https://github.com/haizelabs/haizelabs-python/commit/79056673d41ae7e1edfe91563950b2bf6fda8e9e))
* remove now unused `cached-property` dep ([#32](https://github.com/haizelabs/haizelabs-python/issues/32)) ([925f614](https://github.com/haizelabs/haizelabs-python/commit/925f6147fe044e10547f15efbf7bfbc66abae128))

## 0.1.0-alpha.8 (2024-11-19)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* **api:** api update ([#25](https://github.com/haizelabs/haizelabs-python/issues/25)) ([4ac4cbc](https://github.com/haizelabs/haizelabs-python/commit/4ac4cbcce537f33540c3a1205bb4d1657a59aac6))

## 0.1.0-alpha.7 (2024-11-19)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** api update ([#22](https://github.com/haizelabs/haizelabs-python/issues/22)) ([538226a](https://github.com/haizelabs/haizelabs-python/commit/538226a4eaa98c4abb10007a248612a4b94643a5))

## 0.1.0-alpha.6 (2024-11-19)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** api update ([#19](https://github.com/haizelabs/haizelabs-python/issues/19)) ([8a17514](https://github.com/haizelabs/haizelabs-python/commit/8a17514ee49b4dbce0bcfc7fb9bc52ab3105f8cc))

## 0.1.0-alpha.5 (2024-11-19)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** manual updates ([#17](https://github.com/haizelabs/haizelabs-python/issues/17)) ([83b94a5](https://github.com/haizelabs/haizelabs-python/commit/83b94a5865f76a15c5fd7442bb38fe0dcebe4492))

## 0.1.0-alpha.4 (2024-11-19)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** manual updates ([#14](https://github.com/haizelabs/haizelabs-python/issues/14)) ([88e5ee7](https://github.com/haizelabs/haizelabs-python/commit/88e5ee7363f346a0aff64c31f00dea5fbff19dbf))

## 0.1.0-alpha.3 (2024-11-19)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** api update ([#11](https://github.com/haizelabs/haizelabs-python/issues/11)) ([f5d99c9](https://github.com/haizelabs/haizelabs-python/commit/f5d99c9f3b87515cad9236785e8e7207036b3ab3))

## 0.1.0-alpha.2 (2024-11-19)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/haizelabs/haizelabs-python/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** api update ([#10](https://github.com/haizelabs/haizelabs-python/issues/10)) ([9137364](https://github.com/haizelabs/haizelabs-python/commit/9137364101f114cabd1a17561d8a1ad3e34bae6b))
* **api:** api update ([#7](https://github.com/haizelabs/haizelabs-python/issues/7)) ([13abe44](https://github.com/haizelabs/haizelabs-python/commit/13abe4445e6c00460b00b0908b4538f438dac128))

## 0.1.0-alpha.1 (2024-11-18)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/haizelabs/haizelabs-python/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([273aa31](https://github.com/haizelabs/haizelabs-python/commit/273aa31e4d13c2752404672fd714bc562c1196fb))


### Chores

* go live ([#1](https://github.com/haizelabs/haizelabs-python/issues/1)) ([00a93ef](https://github.com/haizelabs/haizelabs-python/commit/00a93efe6c66de9054a0af1bdd91bbe50068808e))
* rebuild project due to codegen change ([#3](https://github.com/haizelabs/haizelabs-python/issues/3)) ([7d08ef9](https://github.com/haizelabs/haizelabs-python/commit/7d08ef95542499cd18c073e180cc1f57673eacbd))
* rebuild project due to codegen change ([#5](https://github.com/haizelabs/haizelabs-python/issues/5)) ([c804e1a](https://github.com/haizelabs/haizelabs-python/commit/c804e1af0aead936762e33feb75754962e46ddb7))
